qustop.State
============

.. currentmodule:: qustop

.. autoclass:: State

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~State.__init__
      ~State.kron
      ~State.swap
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~State.alice_systems
      ~State.bob_systems
      ~State.dims
      ~State.is_pure
      ~State.shape
      ~State.systems
      ~State.value
   
   